/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

// JUnit classes
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 *  This is a test case for the <code>{@link DTDUtils}</code> class.
 * </p>
 * 
 * @author Robert Sese
 * @author Brett McLaughlin
 */
public class NamingUtilsTest extends TestCase {
   
    /**
     * <p>
     *  This constructs a new <code>NamingUtilsTest</code>.
     * </p>
     *
     * @param name the name of the test case.
     */
    public NamingUtilsTest(String name) {
        super(name);
    }

    /**
     * <p>
     *  This method maeks it easier to call these
     *    tests dynamically.
     * </p>
     *
     * @return <code>TestSuite</code> - corresponds to this 
     *         <code>TestCase</code>.
     */
    public static Test suite(){
        return new TestSuite(NamingUtilsTest.class);
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#getCharMapping}</code> 
     *    method.
     * </p>
     */
    public void testGetCharMapping() {
        Character ch = new Character('.');
        String replaceString = "DOT";
        NamingUtils.setCharMapping(ch, replaceString);
        assertEquals(replaceString, NamingUtils.getCharMapping(ch));
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#setCharMapping}</code> 
     *    method.
     * </p>
     */
    public void testSetCharMapping() {
        Character ch = new Character('.');
        String replaceString = "DOT";
        NamingUtils.setCharMapping(ch, replaceString);
        assertEquals(replaceString, NamingUtils.getCharMapping(ch));
        
        replaceString = "OTHER_DOT";
        NamingUtils.setCharMapping(ch, replaceString);
        assertEquals(replaceString, NamingUtils.getCharMapping(ch));
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#isLegalJavaClassName}</code> 
     *    method.
     * </p>
     */
    public void testIsLegalJavaClassName() {
        String className = "LegalClassName";
        assertTrue(NamingUtils.isLegalJavaClassName(className));
        
        className = "#illegalClassName";
        assertTrue(!NamingUtils.isLegalJavaClassName(className));
        
        className = "9illegalClassName";
        assertTrue(!NamingUtils.isLegalJavaClassName(className));
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#isLegalJavaPackageName}</code> 
     *    method.
     * </p>
     */
    public void testIsLegalJavaPackageName() {
        String packageName = "packageName";
        assertTrue(NamingUtils.isLegalJavaPackageName(packageName));
        
        packageName = "legal.package.name";
        assertTrue(NamingUtils.isLegalJavaPackageName(packageName));
        
        packageName = "9illegal.package";
        assertTrue(!NamingUtils.isLegalJavaPackageName(packageName));
        
        packageName = "#987654";
        assertTrue(!NamingUtils.isLegalJavaPackageName(packageName));
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#getJavaName}</code> method.
     * </p>
     */
    public void testGetJavaName() {
        String name = "my-element";
        String expected = "myElement";
        String actual = NamingUtils.getJavaName(name);

        assertEquals(expected, actual);
    }

    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#getJavaVariableName}</code> 
     *    method.
     * </p>
     */
    public void testGetJavaVariableName() {
        String name = "My-class";
        String expected = "myClass";
        String actual = NamingUtils.getJavaVariableName(name);
        assertEquals(expected, actual);
        
        name = "import";
        expected = "xmlimport";
        actual = NamingUtils.getJavaVariableName(name);
        assertEquals(expected, actual);
    }

    /**
     * <p>
     *  This tests the 
     *    <code>{@link NamingUtils#getJavaCollectionVariableName}</code> 
     *    method.
     * </p>
     */
    public void testGetJavaCollectionVariableName() {
        String name = "My-class";
        String expected = "myClass";
        String actual = NamingUtils.getJavaCollectionVariableName(name);

        assertEquals(expected, actual);
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#getJavaClassName}</code> method.
     * </p>
     */
    public void testGetJavaClassName() {
        String name = "my-element";
        String expected = "MyElement";
        String actual = NamingUtils.getJavaClassName(name);

        assertEquals(expected, actual);
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#getJavaType}</code> 
     *    method.
     * </p>
     */
    public void testGetJavaType() {
        String name = "string";
        String expected = "String";
        String actual = NamingUtils.getJavaType(name);

        assertEquals(expected, actual);
    }

    /**
     * <p>
     *  This tests the 
     *    <code>{@link NamingUtils#getXMLElementNameFromAccessor}</code> 
     *    method.
     * </p>
     */
    public void testGetXMLElementNameFromAccessor() {
        String name = "getMyElement";
        String expected = "myElement";
        String actual = NamingUtils.getXMLElementNameFromAccessor(name);

        assertEquals(expected, actual);
    }
    
    /**
     * <p>
     *  This tests the <code>{@link NamingUtils#removePackage}</code> method.
     * </p>
     */
    public void testRemovePackage() {
        String name = "java.util.List";
        String expected = "List";
        assertEquals(expected, NamingUtils.removePackage(name));
        
        name = "SomeClass";
        expected = name;
        assertEquals(expected, NamingUtils.removePackage(name));
    }
}
